/*
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.social.soundcloud.api.impl;

import org.springframework.social.soundcloud.api.ResolveOperations;
import org.springframework.social.soundcloud.api.SoundCloudProfile;
import org.springframework.social.soundcloud.api.UserOperations;
import org.springframework.social.soundcloud.api.UsersOperations;
import org.springframework.web.client.RestTemplate;

public class UsersTemplate extends AbstractSoundCloudOperations implements UsersOperations {

	public UsersTemplate(String clientId,RestTemplate restTemplate, boolean isAuthorizedForUser) {
		super(clientId,restTemplate, isAuthorizedForUser);
	}

	@Override
	public UserOperations userOperations(long userId) {
		return new UserTemplate(clientId,restTemplate,userId,isAuthorizedForUser);
	}
	
	@Override
	public UserOperations userOperations(String username) {
		ResolveOperations resolveOperations = new ResolveTemplate(clientId,restTemplate,isAuthorizedForUser);
		SoundCloudProfile soundCloudProfile = resolveOperations.resolveUserProfile(username);
		return new UserTemplate(clientId,restTemplate,Long.parseLong(soundCloudProfile.getId()),isAuthorizedForUser);
	}


}
